prompt/prompt library
Functions
-
getPrompts(
{required RawConfig rawConfig, required I18nLocale targetLocale, required GptConfig config, required String? namespace, required String? description, required Map< String, dynamic> translations}) → List<GptPrompt> - Returns the prompts that should be sent to GPT. There can be multiple prompts if the input is too long.